@@ -51,16 +51,9 @@
 #' }
 osrmIsochrone <- function(loc, breaks = seq(from = 0,to = 60, length.out = 7), 
                           exclude = NULL, res = 30, returnclass = "sp"){
-  # library(osrm)
-  # library(sf)
-  # loc = c(-149.8919,61.21981)
-  # breaks = seq(from = 0,to = 60, by = 60) 
-  # exclude = NULL
-  # res = 30
-  # returnclass = "sf"
   # imput mngmnt
   oprj <- NA
-  if(testSp(loc)){
+  if (methods::is(loc,"Spatial")){
     loc <- st_as_sf(loc[1,])
   }    
   if(testSf(loc)){
@@ -131,18 +124,19 @@ osrmIsochrone <- function(loc, breaks = seq(from = 0,to = 60, length.out = 7),
   rpt <- st_as_sf(destinations, coords = c('lon', 'lat'), crs = 4326)
   rpt <- st_transform(rpt, st_crs(loc))
   rpt$durations <- durations
-  b <- as.numeric(st_distance(sgrid[1,], sgrid[2,])/2)
+  b <- as.numeric(st_distance(sgrid[1,], sgrid[2,]) / 2)
   xx <- st_make_grid(x = st_buffer(st_union(sgrid), b), n = c(res, res))
   inter <- st_intersects(xx, rpt)
   sgrid$durations <- unlist(lapply(inter, function(x)mean(rpt[["durations"]][x], na.rm=TRUE)))
-  sgrid[is.nan(sgrid$durations), "durations"] <- tmax+1
-  sgrid[sgrid$durations>tmax, "durations"] <- tmax+1
-  if(min(sgrid$durations)>tmax){
+  sgrid[is.nan(sgrid$durations), "durations"] <- tmax + 1
+  sgrid[sgrid$durations > tmax, "durations"] <- tmax + 1
+  if(min(sgrid$durations) > tmax){
     e <- "Use lower values for 'breaks' or increase 'res'"
     stop(e, call. = FALSE)
   }
   ########### END OF QUICK FIX ################
-    # computes isopolygones
+  
+  # computes isopolygones
   iso <- isopoly(x = sgrid, breaks = breaks, var = "durations")
   
   # proj mgmnt
